#!/usr/bin/python
#	
#	updateSite.py - Part of PubTal
#
#	Usage: updateSite.py site.config [content-dir | content-file] [...]
#
#	Copyright (c) 2003 Colin Stewart (http://www.owlfish.com/)
#	All rights reserved.
#		
#	Redistribution and use in source and binary forms, with or without
#	modification, are permitted provided that the following conditions
#	are met:
#	1. Redistributions of source code must retain the above copyright
#	   notice, this list of conditions and the following disclaimer.
#	2. Redistributions in binary form must reproduce the above copyright
#	   notice, this list of conditions and the following disclaimer in the
#	   documentation and/or other materials provided with the distribution.
#	3. The name of the author may not be used to endorse or promote products
#	   derived from this software without specific prior written permission.
#		
#	THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
#	IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
#	OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#	IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
#	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
#	NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
#	DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
#	THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
#	THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#	
#	If you make any bug fixes or feature enhancements please let me know!
#

try:
	import logging
	logging.basicConfig()
	root = logging.getLogger()
	#root.setLevel (logging.DEBUG)
	root.setLevel (logging.INFO)
	talLogger = logging.getLogger ("simpleTAL")
	talLogger.setLevel (logging.INFO)
	talesLogger = logging.getLogger ("simpleTALES")
	talesLogger.setLevel (logging.INFO)

except:
	from pubtal import InfoLogging as logging
	
import sys, os.path, os, stat
import pubtal

from pubtal import SitePublisher, SiteConfiguration, SiteUtils

class UpdateSite:
	def __init__ (self, configFile, path=None):
		self.config = SiteConfiguration.SiteConfig (configFile)
		self.pathResolver = SiteUtils.PathResolver (self.config)
		self.target = path
		self.log = logging.getLogger ("UpdateSite")
		self.publisher = SitePublisher.PagePublisher (self.config)
		
	def buildSite (self):
		pathsToBuild = self.pathResolver.getPages (self.target)
		self.log.debug ("Found paths: %s" % str (pathsToBuild))
		for aPage in pathsToBuild:
			self.log.info ("Publishing: %s" % str (aPage))
			self.publisher.publish (aPage)
		
if __name__ == '__main__':
	#logging.debug ("Arguments: " + str (sys.argv))
	if (len (sys.argv) < 2):
		print "Usage: %s configFile [paths]" % sys.argv[0]
		sys.exit (1)
		
	if (len (sys.argv) == 2):
		target = None
	else:
		target = sys.argv [2:]
			
	update = UpdateSite (sys.argv[1], target)
	update.buildSite()
